<h1 align="center"  size="40px">
Algebra Linear 
</h1>

Biblioteca criada para me auxiliar nas correções dos exercícios da matéria de Algebra Linear 1 do curso de Ciência da Computação da UFRRJ, e para praticar programação.

## Installation

Use the package manager pip to install Algebra_Linear

```bash
pip install Algebra_Linear
```

## Usage

```python
from Algebra_Linear import Matriz.py
Matriz.simetrica()
```

```python
from Algebra_Linear import Vetor.py
ve = Vetor()
ve.metodosDoObjeto()
```

## Author

Dirceu Silvestre

## License

[MIT](https://choosealicense.com/licenses/mit/)
